@@ -21,6 +21,41 @@ class ConfigFiducialBinary(JavaConfig):
             self.targetWidth = float(target_width)
 
 
+class ConfigHammingMarker(JavaConfig):
+    def __init__(self, target_width=None):
+        JavaConfig.__init__(self, "boofcv.factory.fiducial.ConfigHammingMarker")
+        if target_width is not None:
+            self.targetWidth = float(target_width)
+
+
+class ConfigFiducialHammingDetector(JavaConfig):
+    def __init__(self, config=None):
+        if config:
+            JavaConfig.__init__(self, config)
+        else:
+            JavaConfig.__init__(self, "boofcv.factory.fiducial.ConfigFiducialHammingDetector")
+
+
+class HammingDictionary:
+    """
+    List of prebuilt hamming dictionaries
+    """
+    CUSTOM = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.CUSTOM
+    ARUCO_ORIGINAL = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.ARUCO_ORIGINAL
+    ARUCO_MIP_16h3 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.ARUCO_MIP_16h3
+    ARUCO_MIP_25h7 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.ARUCO_MIP_25h7
+    ARUCO_MIP_36h12 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.ARUCO_MIP_36h12
+    ARUCO_OCV_4x4_1000 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.ARUCO_OCV_4x4_1000
+    ARUCO_OCV_5x5_1000 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.ARUCO_OCV_5x5_1000
+    ARUCO_OCV_6x6_1000 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.ARUCO_OCV_6x6_1000
+    ARUCO_OCV_7x7_1000 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.ARUCO_OCV_7x7_1000
+    APRILTAG_16h5 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.APRILTAG_16h5
+    APRILTAG_25h7 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.APRILTAG_25h7
+    APRILTAG_25h9 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.APRILTAG_25h9
+    APRILTAG_36h10 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.APRILTAG_36h10
+    APRILTAG_36h11 = gateway.jvm.boofcv.factory.fiducial.HammingDictionary.APRILTAG_36h11
+
+
 class ConfigGridDimen(JavaConfig):
     def __init__(self, num_rows, num_cols, square_width):
         java_obj = gateway.jvm.boofcv.abst.fiducial.calib.ConfigGridDimen(
@@ -63,223 +98,56 @@ class ConfigQrCode(JavaConfig):
         JavaConfig.__init__(self, "boofcv.factory.fiducial.ConfigQrCode")
 
 
+class ConfigMicroQrCode(JavaConfig):
+    def __init__(self):
+        JavaConfig.__init__(self, "boofcv.factory.fiducial.ConfigMicroQrCode")
+
+
 class ConfigUchiyaMarker(JavaConfig):
     def __init__(self):
         JavaConfig.__init__(self, "boofcv.factory.fiducial.ConfigUchiyaMarker")
 
 
-class FactoryFiducialCalibration:
-    def __init__(self):
-        pass
-
-    @staticmethod
-    def chessboardX(config_grid, config_detector=None):
-        """
-        Creates a chessboard detector based on x-corners. Slower but very robust.
-
-        :param config_detector:  Configuration for the detector
-        :param config_grid: Specifies the Grid's shape
-        :type config_grid: ConfigGridDimen
-        :return: Calibration target detector
-        :rtype: FiducialCalibrationDetector
-        """
-        cdj = None
-        if config_detector:
-            cdj = config_detector.java_obj
-
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration.chessboardX(cdj,
-                                                                                                   config_grid.java_obj)
-        return FiducialCalibrationDetector(java_detector)
-
-    @staticmethod
-    def chessboardB(config_grid, config_detector=None):
-        """
-        Creates a chessboard detector based on binary images. Fast but not as robust.
-
-        :param config_detector:  Configuration for the detector
-        :param config_grid: Specifies the Grid's shape
-        :type config_grid: ConfigGridDimen
-        :return: Calibration target detector
-        :rtype: FiducialCalibrationDetector
-        """
-        cdj = None
-        if config_detector:
-            cdj = config_detector.java_obj
-
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration.chessboardB(cdj,
-                                                                                                   config_grid.java_obj)
-        return FiducialCalibrationDetector(java_detector)
-
-    @staticmethod
-    def square_grid(config_grid, config_detector=None):
-        """
-        Creates a square grid detector
-
-        :param config_detector:  Configuration for the detector
-        :param config_grid: Specifies the Grid's shape
-        :type config_grid: ConfigGridDimen
-        :return: Calibration target detector
-        :rtype: FiducialCalibrationDetector
-        """
-        cdj = None
-        if config_detector:
-            cdj = config_detector.java_obj
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration.squareGrid(cdj,
-                                                                                                  config_grid.java_obj)
-        return FiducialCalibrationDetector(java_detector)
-
-    @staticmethod
-    def circle_hexagonal_grid(config_grid, config_detector=None):
-        """
-        Detector for hexagonal grid of circles.  All circles must be entirely inside of the image.
-
-        :param config_detector:  Configuration for the detector
-        :param config_grid: Specifies the Grid's shape
-        :type config_grid: ConfigGridDimen
-        :return: Calibration target detector
-        :rtype: FiducialCalibrationDetector
-        """
-        cdj = None
-        if config_detector:
-            cdj = config_detector.java_obj
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration. \
-            circleHexagonalGrid(cdj, config_grid.java_obj)
-        return FiducialCalibrationDetector(java_detector)
-
-    @staticmethod
-    def circle_regular_grid(config_grid, config_detector=None):
-        """
-        Detector for regular grid of circles.  All circles must be entirely inside of the image.
-
-        :param config_detector:  Configuration for the detector
-        :param config_grid: Specifies the Grid's shape
-        :return: Calibration target detector
-        :rtype: FiducialCalibrationDetector
-        """
-        cdj = None
-        if config_detector:
-            cdj = config_detector.java_obj
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration. \
-            circleRegularGrid(cdj, config_grid.java_obj)
-        return FiducialCalibrationDetector(java_detector)
-
-
-class FactoryFiducial:
-    def __init__(self, dtype):
-        """
-        Configures factory for the specific image type
-        :param dtype: Type of single band image
-        """
-        self.boof_image_type = dtype_to_Class_SingleBand(dtype)
-
-    def square_image(self, config_fiducial, config_threshold):
-        """
-        Creates a square image fiducial detector
-
-        :param config_fiducial: configuration for the fiducial
-        :type config_fiducial: ConfigFiducialImage
-        :param config_threshold: Configuration for image thresholding step
-        :type config_threshold: ConfigThreshold
-        :return: The detector
-        :rtype: FiducialImageDetector
-        """
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
-            squareImage(config_fiducial.java_obj, config_threshold.java_obj, self.boof_image_type)
-        return FiducialImageDetector(java_detector)
-
-    def square_binary(self, config_fiducial, config_threshold):
-        """
-        Creates a binary image fiducial detector
-
-        :param config_fiducial: configuration for the fiducial
-        :type config_fiducial: ConfigFiducialBinary
-        :param config_threshold: Configuration for image thresholding step
-        :type config_threshold: ThresholdType
-        :return: The detector
-        :rtype: FiducialImageDetector
-        """
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
-            squareBinary(config_fiducial.java_obj, config_threshold.java_obj, self.boof_image_type)
-        return FiducialDetector(java_detector)
-
-    def chessboardB(self, config_grid, config_detector=None):
-        """
-        Chessboard detector binary image
-
-        :param config_detector: Fiducial configuration
-        :type config_detector: ConfigChessboardBinary
-        :param config_grid: Specifies the Grid's shape
-        :type config_grid: ConfigGridDimen
-        :return: FiducialDetector
-        :rtype: FiducialDetector
-        """
-        cdj = None
-        if config_detector:
-            cdj = config_detector.java_obj
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
-            calibChessboardB(cdj, config_grid.java_obj, self.boof_image_type)
-        return FiducialDetector(java_detector)
-
-    def chessboardX(self, config_grid, config_detector=None):
-        """
-        Chessboard detector X-corner
-
-        :param config_detector: Fiducial configuration
-        :type config_detector: ConfigChessboardX
-        :param config_grid: Specifies the Grid's shape
-        :type config_grid: ConfigGridDimen
-        :return: FiducialDetector
-        :rtype: FiducialDetector
-        """
-        cdj = None
-        if config_detector:
-            cdj = config_detector.java_obj
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
-            calibChessboardX(cdj, config_grid.java_obj, self.boof_image_type)
-        return FiducialDetector(java_detector)
-
-    def square_grid(self, config_grid, config_detector=None):
-        """
-        Square grid detector
-
-        :param config_detector: Fiducial configuration
-        :type config_detector: ConfigFiducialSquareGrid
-        :param config_grid: Specifies the Grid's shape
-        :type config_grid: ConfigGridDimen
-        :return: FiducialDetector
-        :rtype: FiducialDetector
-        """
-        cdj = None
-        if config_detector:
-            cdj = config_detector.java_obj
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
-            calibSquareGrid(cdj, config_grid.java_obj, self.boof_image_type)
-        return FiducialDetector(java_detector)
-
-    def qrcode(self, config=None):
-        """ Creates a detector for QR Codes
-
-        :param config: ConfigQrCode or None
-        :return: QrCodeDetector
-        """
-        if config is None:
-            jconf = None
+class ConfigECoCheckMarkers(JavaConfig):
+    def __init__(self, java_config=None):
+        if java_config:
+            JavaConfig.__init__(self, java_config)
         else:
-            jconf = config.java_obj
+            JavaConfig.__init__(self, "boofcv.abst.fiducial.calib.ConfigECoCheckMarkers")
 
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
-            qrcode(jconf, self.boof_image_type)
-        return QrCodeDetector(java_detector)
 
-    def random_dots(self, config):
-        """ Creates a detector random dot / Uchiya markers
+class ConfigECoCheckDetector(JavaConfig):
+    def __init__(self):
+        JavaConfig.__init__(self, "boofcv.abst.fiducial.calib.ConfigECoCheckDetector")
 
-        :param config: ConfigUchiyaMarker or None
-        :return: ConfigUchiyaMarker
-        """
-        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
-            randomDots(config.java_obj, self.boof_image_type)
-        return UchiyaRandomDotDetector(java_detector)
+
+def ecocheck_parse(description: str, square_size: float) -> ConfigECoCheckMarkers:
+    """
+    Parses string summary of an ECoCheck marker.
+    Example 9x7n1e3c6, 9x7 grid, 1 marker, ecc=3, checksum=6bits.
+    Example 9x7n2, 9x7 grid, 2 markers, default ecc and checksum.
+
+    :param description: String summary of ECoCheck configuration
+    :param square_size: How big a square in the chessboard pattern is
+    """
+    return ConfigECoCheckMarkers(gateway.jvm.boofcv.abst.fiducial.calib.ConfigECoCheckMarkers.
+                                 parse(description, square_size))
+
+
+def load_hamming_marker(dictionary):
+    """
+    Loads the specified prebuilt dictionary
+
+    :param dictionary: Which dictionary
+    :type dictionary: HammingDictionary
+    :return: Marker configuration
+    :rtype: ConfigFiducialHammingDetector
+    """
+    if dictionary == HammingDictionary.CUSTOM:
+        raise RuntimeError("Custom dictionary")
+
+    return ConfigFiducialHammingDetector(
+        gateway.jvm.boofcv.factory.fiducial.ConfigHammingMarker.loadDictionary(dictionary))
 
 
 class FiducialCalibrationDetector(JavaWrapper):
@@ -306,6 +174,35 @@ class FiducialCalibrationDetector(JavaWrapper):
             self.detected_points.append((jp.getIndex(), pixel.getX(), pixel.getY()))
 
 
+class FiducialCalibrationDetectorMulti(JavaWrapper):
+    """
+    Calibration fiducial detector which can handle multiple unique markers
+    """
+
+    def __init__(self, java_object):
+        JavaWrapper.__init__(self, java_object)
+        self.detected_markers = []
+        # This is hard coded for a single target right now
+        self.layout = b2p_list_point2D(java_object.getLayout(0), np.double)
+
+    def detect(self, image):
+        self.java_obj.process(image)
+
+        self.detected_markers = []
+        num_detections = self.java_obj.getDetectionCount()
+
+        for detection_idx in range(num_detections):
+            jobs = self.java_obj.getDetectedPoints(detection_idx)
+            marker_id = self.java_obj.getMarkerID(detection_idx)
+            landmarks = []
+            jdetected = self.java_obj.getDetectedPoints(detection_idx)
+            for i in range(jdetected.size()):
+                jp = jdetected.get(i)
+                pixel = jp.getP()
+                landmarks.append((jp.getIndex(), pixel.getX(), pixel.getY()))
+            self.detected_markers.append({"marker": marker_id, "landmarks": landmarks})
+
+
 class FiducialDetector(JavaWrapper):
     """
     Detects fiducials and estimates their ID, 3D pose, and image location.
@@ -318,7 +215,7 @@ class FiducialDetector(JavaWrapper):
     def detect(self, image):
         self.java_obj.detect(image)
 
-    def set_intrinsic(self, intrinsic: CameraPinhole):
+    def set_intrinsic(self, intrinsic):
         if intrinsic is None:
             self.java_obj.setLensDistortion(None, -1, -1)
         else:
@@ -326,26 +223,24 @@ class FiducialDetector(JavaWrapper):
             self.java_obj.setLensDistortion(distortion.java_obj,
                                             intrinsic.width, intrinsic.height)
 
-    def get_total(self):
+    def get_total(self) -> int:
         return self.java_obj.totalFound()
 
-    def is_3d(self):
+    def is_3d(self) -> bool:
         return self.java_obj.is3D()
 
-    def get_fiducial_to_camera(self, which):
+    def get_fiducial_to_camera(self, which: int) -> Se3_F64:
         """
         Returns the rigid body transform from the fiducial to the camera
 
         :param which: Index of detected fiducial.
-        :type which: int
         :return: Rigid Body Transform
-        :rtype: Se3_F64
         """
         fid_to_cam = Se3_F64()
         self.java_obj.getFiducialToCamera(which, fid_to_cam.get_java_object())
         return fid_to_cam
 
-    def get_bounds(self, which):
+    def get_bounds(self, which) -> Polygon2D:
         return Polygon2D(self.java_obj.getBounds(which, None))
 
     def get_center(self, which):
@@ -356,10 +251,10 @@ class FiducialDetector(JavaWrapper):
     def get_id(self, which):
         return self.java_obj.getId(which)
 
-    def get_width(self, which):
+    def get_width(self, which) -> int:
         return self.java_obj.getWidth(which)
 
-    def get_input_type(self):
+    def get_input_type(self) -> ImageType:
         return ImageType(self.java_obj.get_input_type())
 
 
@@ -424,6 +319,58 @@ class QrCodeDetector(JavaWrapper):
         return ImageType(self.java_obj.getImageType())
 
 
+class MicroQrCode:
+    """Description of a detected Micro QR Code inside an image.
+
+    """
+
+    def __init__(self, java_object=None):
+        if java_object is None:
+            self.verson = -1
+            self.message = ""
+            self.error_level = ""
+            self.mask_pattern = ""
+            self.mode = ""
+            self.failure_cause = ""
+            self.bounds = Polygon2D(4)
+            self.pp = Polygon2D(4)
+        else:
+            jobj = JavaWrapper(java_object)
+            self.verson = jobj.version
+            self.message = jobj.message
+            self.error_level = jobj.error.toString()
+            self.mask_pattern = jobj.mask.toString()
+            self.mode = jobj.mode.toString()
+            self.failure_cause = ""
+            self.bounds = Polygon2D(jobj.bounds)
+            self.pp = Polygon2D(jobj.pp)
+
+            if jobj.failureCause is not None:
+                self.failure_cause = jobj.failureCause.toString()
+
+
+class MicroQrDetector(JavaWrapper):
+    """Detects Micro QR Codes inside of images
+
+    Attributes:
+        detections: List of detected MicroQrCode
+        failures: List of objects that are highly likely to be a QR Code but were rejected.
+    """
+
+    def __init__(self, java_detector):
+        JavaWrapper.__init__(self, java_detector)
+        self.detections = []
+        self.failures = []
+
+    def detect(self, image):
+        self.java_obj.process(image)
+        self.detections = [MicroQrCode(x) for x in self.java_obj.getDetections()]
+        self.failures = [MicroQrCode(x) for x in self.java_obj.getFailures()]
+
+    def get_image_type(self):
+        return ImageType(self.java_obj.getImageType())
+
+
 class UchiyaRandomDotDetector(FiducialDetector):
     """Detector for random dot markers
     """
@@ -437,6 +384,255 @@ class UchiyaRandomDotDetector(FiducialDetector):
         self.java_obj.addMarker(marker)
 
 
+class FactoryFiducialCalibration:
+    def __init__(self):
+        pass
+
+    @staticmethod
+    def chessboardX(config_grid: ConfigGridDimen,
+                    config_detector: ConfigChessboardX = None) -> FiducialCalibrationDetector:
+        """
+        Creates a chessboard detector based on x-corners. Slower but very robust.
+
+        :param config_detector:  Configuration for the detector
+        :param config_grid: Specifies the Grid's shape
+        :return: Calibration target detector
+        """
+        cdj = None
+        if config_detector:
+            cdj = config_detector.java_obj
+
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration. \
+            chessboardX(cdj, config_grid.java_obj)
+        return FiducialCalibrationDetector(java_detector)
+
+    @staticmethod
+    def chessboardB(config_grid: ConfigGridDimen,
+                    config_detector: ConfigChessboardBinary = None) -> FiducialCalibrationDetector:
+        """
+        Creates a chessboard detector based on binary images. Fast but not as robust.
+
+        :param config_detector:  Configuration for the detector
+        :param config_grid: Specifies the Grid's shape
+        :return: Calibration target detector
+        """
+        cdj = None
+        if config_detector:
+            cdj = config_detector.java_obj
+
+        java_detector = gateway.jvm.boofcv.factory.fiducial. \
+            FactoryFiducialCalibration.chessboardB(cdj, config_grid.java_obj)
+        return FiducialCalibrationDetector(java_detector)
+
+    @staticmethod
+    def ecocheck(config_marker: ConfigECoCheckMarkers, config_detector: ConfigECoCheckDetector = None) \
+            -> FiducialCalibrationDetectorMulti:
+        """
+        Create an ECoCheck detector.
+
+        :param config_marker:  Configuration for marker
+        :param config_detector: Specifies how to detect the marker
+        :return: Calibration target detector
+        """
+        jdetector = None
+        if config_detector:
+            jdetector = config_detector.java_obj
+
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration. \
+            ecocheck(jdetector, config_marker.java_obj)
+        return FiducialCalibrationDetectorMulti(java_detector)
+
+    @staticmethod
+    def square_grid(config_grid: ConfigGridDimen,
+                    config_detector: ConfigSquareGrid = None) -> FiducialCalibrationDetector:
+        """
+        Creates a square grid detector
+
+        :param config_detector:  Configuration for the detector
+        :param config_grid: Specifies the Grid's shape
+        :return: Calibration target detector
+        """
+        cdj = None
+        if config_detector:
+            cdj = config_detector.java_obj
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration.squareGrid(cdj,
+                                                                                                  config_grid.java_obj)
+        return FiducialCalibrationDetector(java_detector)
+
+    @staticmethod
+    def circle_hexagonal_grid(config_grid: ConfigGridDimen,
+                              config_detector: ConfigCircleHexagonalGrid = None) -> FiducialCalibrationDetector:
+        """
+        Detector for hexagonal grid of circles.  All circles must be entirely inside of the image.
+
+        :param config_detector:  Configuration for the detector
+        :param config_grid: Specifies the Grid's shape
+        :return: Calibration target detector
+        """
+        cdj = None
+        if config_detector:
+            cdj = config_detector.java_obj
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration. \
+            circleHexagonalGrid(cdj, config_grid.java_obj)
+        return FiducialCalibrationDetector(java_detector)
+
+    @staticmethod
+    def circle_regular_grid(config_grid: ConfigGridDimen,
+                            config_detector: ConfigCircleRegularGrid = None) -> FiducialCalibrationDetector:
+        """
+        Detector for regular grid of circles.  All circles must be entirely inside of the image.
+
+        :param config_detector:  Configuration for the detector
+        :param config_grid: Specifies the Grid's shape
+        :return: Calibration target detector
+        """
+        cdj = None
+        if config_detector:
+            cdj = config_detector.java_obj
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducialCalibration. \
+            circleRegularGrid(cdj, config_grid.java_obj)
+        return FiducialCalibrationDetector(java_detector)
+
+
+class FactoryFiducial:
+    def __init__(self, dtype):
+        """
+        Configures factory for the specific image type
+        :param dtype: Type of single band image
+        """
+        self.boof_image_type = dtype_to_Class_SingleBand(dtype)
+
+    def square_image(self, config_fiducial: ConfigFiducialImage,
+                     config_threshold: ConfigThreshold) -> FiducialImageDetector:
+        """
+        Creates a square image fiducial detector
+
+        :param config_fiducial: configuration for the fiducial
+        :param config_threshold: Configuration for image thresholding step
+        :return: The detector
+        """
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
+            squareImage(config_fiducial.java_obj, config_threshold.java_obj, self.boof_image_type)
+        return FiducialImageDetector(java_detector)
+
+    def square_binary(self, config_fiducial: ConfigFiducialBinary, config_threshold: ThresholdType) -> FiducialDetector:
+        """
+        Creates a binary image fiducial detector
+
+        :param config_fiducial: configuration for the fiducial
+        :param config_threshold: Configuration for image thresholding step
+        :return: The detector
+        """
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
+            squareBinary(config_fiducial.java_obj, config_threshold.java_obj, self.boof_image_type)
+        return FiducialDetector(java_detector)
+
+    def square_hamming(self, config_fiducial: ConfigHammingMarker,
+                       config_detector: ConfigFiducialHammingDetector = None):
+        """
+        Creates a binary image fiducial detector
+
+        :param config_fiducial: configuration for the fiducial
+        :param config_threshold: Configuration for image thresholding step
+        :return: The detector
+        """
+        jconfig_detector = None
+        if config_detector:
+            jconfig_detector = config_detector.java_obj
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
+            squareHamming(config_fiducial.java_obj, jconfig_detector, self.boof_image_type)
+        return FiducialDetector(java_detector)
+
+    def chessboardB(self, config_grid: ConfigGridDimen,
+                    config_detector: ConfigChessboardBinary = None) -> FiducialDetector:
+        """
+        Chessboard detector binary image
+
+        :param config_grid: Specifies the Grid's shape
+        :param config_detector: Fiducial configuration
+        :return: FiducialDetector
+        :rtype: FiducialDetector
+        """
+        cdj = None
+        if config_detector:
+            cdj = config_detector.java_obj
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
+            calibChessboardB(cdj, config_grid.java_obj, self.boof_image_type)
+        return FiducialDetector(java_detector)
+
+    def chessboardX(self, config_grid: ConfigGridDimen, config_detector: ConfigChessboardX = None) -> FiducialDetector:
+        """
+        Chessboard detector X-corner
+
+        :param config_grid: Specifies the Grid's shape
+        :param config_detector: Fiducial configuration
+        :return: FiducialDetector
+        """
+        cdj = None
+        if config_detector:
+            cdj = config_detector.java_obj
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
+            calibChessboardX(cdj, config_grid.java_obj, self.boof_image_type)
+        return FiducialDetector(java_detector)
+
+    def square_grid(self, config_grid: ConfigGridDimen,
+                    config_detector: ConfigSquareGrid = None) -> FiducialDetector:
+        """
+        Square grid detector
+
+        :param config_detector: Fiducial configuration
+        :param config_grid: Specifies the Grid's shape
+        :return: FiducialDetector
+        """
+        cdj = None
+        if config_detector:
+            cdj = config_detector.java_obj
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
+            calibSquareGrid(cdj, config_grid.java_obj, self.boof_image_type)
+        return FiducialDetector(java_detector)
+
+    def qrcode(self, config: ConfigQrCode = None) -> QrCodeDetector:
+        """ Creates a detector for QR Codes
+
+        :param config: ConfigQrCode or None
+        :return: QrCodeDetector
+        """
+        if config is None:
+            jconf = None
+        else:
+            jconf = config.java_obj
+
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
+            qrcode(jconf, self.boof_image_type)
+        return QrCodeDetector(java_detector)
+
+    def microqr(self, config: ConfigMicroQrCode = None) -> MicroQrDetector:
+        """ Creates a detector for Micro QR Codes
+
+        :param config: ConfigMicroQrCode or None
+        :return: MicroQrDetector
+        """
+        if config is None:
+            jconf = None
+        else:
+            jconf = config.java_obj
+
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
+            microqr(jconf, self.boof_image_type)
+        return MicroQrDetector(java_detector)
+
+
+    def random_dots(self, config: ConfigUchiyaMarker) -> UchiyaRandomDotDetector:
+        """ Creates a detector random dot / Uchiya markers
+
+        :param config: ConfigUchiyaMarker or None
+        :return: ConfigUchiyaMarker
+        """
+        java_detector = gateway.jvm.boofcv.factory.fiducial.FactoryFiducial. \
+            randomDots(config.java_obj, self.boof_image_type)
+        return UchiyaRandomDotDetector(java_detector)
+
+
 def string_to_qrcode_error(error):
     if error == "L":
         return gateway.jvm.boofcv.alg.fiducial.qrcode.QrCode.ErrorLevel.L
@@ -471,6 +667,30 @@ def int_to_qrcode_mask(mask):
         return None
 
 
+def string_to_microqr_error(error):
+    if error == "L":
+        return gateway.jvm.boofcv.alg.fiducial.microqr.MicroQrCode.ErrorLevel.L
+    elif error == "M":
+        return gateway.jvm.boofcv.alg.fiducial.microqr.MicroQrCode.ErrorLevel.M
+    elif error == "Q":
+        return gateway.jvm.boofcv.alg.fiducial.microqr.MicroQrCode.ErrorLevel.Q
+    else:
+        return None
+
+
+def int_to_microqr_mask(mask):
+    if mask == 0b00:
+        return gateway.jvm.boofcv.alg.fiducial.microqr.MicroQrCodeMaskPattern.M000
+    elif mask == 0b01:
+        return gateway.jvm.boofcv.alg.fiducial.microqr.MicroQrCodeMaskPattern.M001
+    elif mask == 0b10:
+        return gateway.jvm.boofcv.alg.fiducial.microqr.MicroQrCodeMaskPattern.M010
+    elif mask == 0b11:
+        return gateway.jvm.boofcv.alg.fiducial.microqr.MicroQrCodeMaskPattern.M011
+    else:
+        return None
+
+
 class QrCodeGenerator:
     """Converts a message into a QR Code that meets your specification
 
@@ -510,6 +730,84 @@ class QrCodeGenerator:
         return self.java_generator.getGray()
 
 
+class MicroQrCodeGenerator:
+    """Converts a message into a Micro QR Code that meets your specification
+    """
+
+    def __init__(self, pixels_per_module=4):
+        self.pixels_per_module = int(pixels_per_module)
+        self.java_encoder = gateway.jvm.boofcv.alg.fiducial.microqr.MicroQrCodeEncoder()
+        self.java_generator = gateway.jvm.boofcv.alg.fiducial.microqr.MicroQrCodeGenerator()
+        self.java_engine = gateway.jvm.boofcv.alg.drawing.FiducialImageEngine()
+        self.java_generator.setRender(self.java_engine)
+
+    def reset(self):
+        self.java_encoder.reset()
+
+    def set_version(self, version):
+        self.java_encoder.setVersion(version)
+
+    def set_error(self, level):
+        """Specifies error level for encoded Micro QR Code
+
+        :param level: String that can be "L","M","Q"
+        """
+        self.java_encoder.setError(string_to_microqr_error(level))
+
+    def set_mask(self, mask):
+        """Specifies the type of mask to use. If not specified then it's automatically selected.
+        Probably shouldn't mess with this unless you have a very good reason.
+
+        :param mask: 0b00, 0b01, 0b11, 0b10
+        """
+        self.java_encoder.setMask(string_to_microqr_error(mask))
+
+    def set_message(self, message):
+        self.java_encoder.addAutomatic(str(message))
+
+    def generate(self):
+        qr = self.java_encoder.fixate()
+        pixel_width = qr.getNumberOfModules() * self.pixels_per_module
+        self.java_engine.configure(0, pixel_width)
+        self.java_generator.setMarkerWidth(float(pixel_width))
+        self.java_generator.render(qr)
+        return self.java_engine.getGray()
+
+
+class SquareHammingGenerator:
+    """
+    Renders hamming type square markers
+    """
+
+    def __init__(self, config, pixels_per_square=4):
+        """
+        Renders hamming type markers
+
+        :param config: Configuration for the marker
+        :type config: ConfigHammingMarker
+        :param pixels_per_square: Number of pixels wide each square is
+        :type pixels_per_square: int
+        """
+        self.border_pixels = 0
+        self.pixels_per_square = pixels_per_square
+        self.java_generator = gateway.jvm.boofcv.alg.fiducial.square.FiducialSquareHammingGenerator(config.java_obj)
+        self.java_engine = gateway.jvm.boofcv.alg.drawing.FiducialImageEngine()
+        self.java_generator.setRenderer(self.java_engine)
+
+    def generate(self, marker_idx):
+        """
+        Renders the specified marker into a gray scale image
+        :param marker_idx: index of the marker to render. An exception is thrown if out of bounds
+        :return: Rendered marker
+        :rtype: BoofCV image type
+        """
+
+        marker_width = self.java_generator.getMarkerWidth()
+        render.configure(whiteBorderPixels, int(marker_width))
+        self.java_generator.generate(marker_idx)
+        return elf.java_engine.getGray()
+
+
 class ConfigCirculant(JavaConfig):
     def __init__(self, java_object=None):
         JavaConfig.__init__(self, java_object)
@@ -695,7 +993,7 @@ class SceneRecognition(JavaWrapper):
 
         # Convert the java results into a python list of dict
         results = []
-        for i in range(java_matches.size()):
+        for i in range(java_matches.size):
             java_match = java_matches.get(i)
             match = JavaWrapper(java_match)
             results.append({"id": match.id, "error": match.error})
@@ -726,14 +1024,12 @@ class FactorySceneRecognition:
         else:
             self.image_type = ImageType(dtype_to_ImageType(image_type))
 
-    def scene_recognition(self, config=None):
+    def scene_recognition(self, config: ConfigFeatureToSceneRecognition = None) -> SceneRecognition:
         """
         Scene recognition based off of image features
 
         :param config: Configuration for scene detector
-        :type config: ConfigFeatureToSceneRecognition
         :return: Calibration target detector
-        :rtype: SceneRecognition
         """
         cdj = None
         if config:
@@ -744,7 +1040,7 @@ class FactorySceneRecognition:
         return SceneRecognition(java_obj)
 
 
-def download_default_scene_recognition(image_type, path=None):
+def download_default_scene_recognition(image_type, path=None) -> SceneRecognition:
     """
     Downloads then loads the default scene recognition model provided by BoofCV. If the model has already been
     saved at the specified location it will not be downloaded again.
@@ -761,7 +1057,6 @@ def download_default_scene_recognition(image_type, path=None):
     path = os.path.abspath(path)
 
     java_file = pyboof.create_java_file(path)
-    java_recognizer = gateway.jvm.boofcv.io.recognition.RecognitionIO.\
+    java_recognizer = gateway.jvm.boofcv.io.recognition.RecognitionIO. \
         downloadDefaultSceneRecognition(java_file, image_type.java_obj)
     return SceneRecognition(java_recognizer)
-
