@@ -6,8 +6,6 @@ from pyboof import gateway
 import pyboof as pb
 import numpy as np
 
-pb.init_memmap()
-
 
 class ChecksFactoryFiducialCalibration(unittest.TestCase):
     """
@@ -19,12 +17,21 @@ class ChecksFactoryFiducialCalibration(unittest.TestCase):
         config_target = pb.ConfigGridDimen(5, 6, 0.30)
 
         pb.FactoryFiducialCalibration.chessboardX(config_target, config_detector)
+        pb.FactoryFiducialCalibration.chessboardX(config_target)
 
     def test_chessboardB(self):
         config_detector = pb.ConfigChessboardBinary()
         config_target = pb.ConfigGridDimen(5, 6, 0.30)
 
         pb.FactoryFiducialCalibration.chessboardB(config_target, config_detector)
+        pb.FactoryFiducialCalibration.chessboardB(config_target)
+
+    def test_ecocheck(self):
+        config_detector = pb.ConfigECoCheckDetector()
+        config_target = pb.ecocheck_parse("5x4n2", 2.0)
+
+        pb.FactoryFiducialCalibration.ecocheck(config_target, config_detector)
+        pb.FactoryFiducialCalibration.ecocheck(config_target)
 
     def test_square_grid(self):
         config_detector = pb.ConfigSquareGrid()
@@ -60,25 +67,33 @@ class ChecksFactoryFiducial(unittest.TestCase):
         config_threshold = pb.ConfigThreshold.create_fixed(50.0)
         pb.FactoryFiducial(np.uint8).square_binary(config_detector, config_threshold)
 
+    def test_square_hamming(self):
+        config_marker = pb.load_hamming_marker(pb.HammingDictionary.ARUCO_ORIGINAL)
+        pb.FactoryFiducial(np.uint8).square_hamming(config_marker)
+
     def test_chessboardB(self):
-        config_detector = pb.ConfigChessboardBinary()
         config_target = pb.ConfigGridDimen(5, 6, 0.30)
+        config_detector = pb.ConfigChessboardBinary()
         pb.FactoryFiducial(np.uint8).chessboardB(config_target, config_detector)
 
     def test_chessboardX(self):
-        config_detector = pb.ConfigChessboardX()
         config_target = pb.ConfigGridDimen(5, 6, 0.30)
+        config_detector = pb.ConfigChessboardX()
         pb.FactoryFiducial(np.uint8).chessboardX(config_target, config_detector)
 
     def test_square_grid(self):
-        config_detector = pb.ConfigSquareGrid()
         config_target = pb.ConfigGridDimen(5, 6, 0.30)
+        config_detector = pb.ConfigSquareGrid()
         pb.FactoryFiducial(np.uint8).square_grid(config_target, config_detector)
 
     def test_qrcode(self):
         config_detector = pb.ConfigQrCode()
         pb.FactoryFiducial(np.uint8).qrcode(config_detector)
 
+    def test_microqrcode(self):
+        config_detector = pb.ConfigMicroQrCode()
+        pb.FactoryFiducial(np.uint8).microqr(config_detector)
+
     def test_random_dots(self):
         config_detector = pb.ConfigUchiyaMarker()
         config_detector.markerWidth = 5.0
